@@ -22,13 +22,13 @@ actionTest :: CmdLine -> IO ()
 actionTest Test{..} = withBuffering stdout NoBuffering $ withTempFile $ \sample -> do
     putStrLn "Code tests"
     general_util_test
-    input_hoogle_test
+    input_haddock_test
     query_test
     action_server_test_
     putStrLn ""
 
     putStrLn "Sample database tests"
-    actionGenerate defaultGenerate{database=sample, local_=Just "misc/sample-data"}
+    actionGenerate defaultGenerate{database=sample, local_=["misc/sample-data"]}
     action_search_test True sample
     action_server_test True sample
     putStrLn ""
