@@ -69,17 +69,9 @@ linesC = loop []
 
 linesCR :: Monad m => Conduit Str m Str
 linesCR = linesC =$= mapC f
-    where f x | Just (x, '\r') <- bsUnsnoc x = x
+    where f x | Just (x, '\r') <- BS.unsnoc x = x
               | otherwise = x
 
-bsUnsnoc :: BS.ByteString -> Maybe (BS.ByteString, Char)
-#if __GLASGOW_HASKELL__ < 708
-bsUnsnoc x | BS.null x = Nothing
-           | otherwise = Just (BS.init x, BS.last x)
-#else
-bsUnsnoc = BS.unsnoc
-#endif
-
 sourceLStr :: Monad m => LStr -> Producer m Str
 sourceLStr = sourceList . lstrToChunks
 
